==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/write.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
$head = _WRITE_REPLY;
if (isset($rid) && KWL_ValidRid($rid)) {
	include("include/header.inc.php");
	$sql  = "SELECT * from T_Comments WHERE Rid = '$rid'";
	$A = SqlQueryFetchArray($sql);
	if (empty($A)) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br>" . _NOSTORY . "<br><br>";
		KWL_DrawMain($VAR);
	} else {
		if ($CONF['ENABLE_QUOTE']) $otxt = KWL_QuoteText($A['Content'],$A['Author']);
		$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
		KWL_DrawComment($A,$where);
		if (isset($aid)) $where .= "&aid=$aid";
		if (isset($story)) $where .= "&story=$story";
		if (isset($p)) $where .= "&p=$p";
		if (isset($cmode)) $where .= "&cmode=$cmode";
		if (isset($comment_sort)) $where .= "&comment_sort=$comment_sort";
		$size['name'] = KWL_FormSize(15);
		$size['text'] = KWL_FormSize(32);
		if ($A['email']) echo "<!-- msg will send via email -->\n";
		KWL_PostComment($rid,$A['TopRid'],$where,$A['score'],1,$otxt);
	}
} else if(isset($sid)) {
	include("include/header.inc.php");
	$A = KWL_GetStory($sid);
	if (!$A) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br>" . _NOSTORY . "<br><br>";
		KWL_DrawMain($VAR);
	} else {
		KWL_DrawStory($A);
		echo "<BR>\n";
		if ($CONF['ENABLE_QUOTE']) $otxt = KWL_QuoteText($A['Content'],$A['Author']);
		KWL_PostComment($sid,$sid,"comments.php?rid=$sid&amp;story=$sid&amp;bm=1",'','',$otxt);
	}
} else KWL_Redirect("$CONF[G_URL]");
include("include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/write.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
$head = _WRITE_REPLY;
if (isset($rid) && KWL_ValidRid($rid)) {
	include("include/header.inc.php");
	$sql  = "SELECT * from T_Comments WHERE Rid = '$rid'";
	$A = SqlQueryFetchArray($sql);
	if (empty($A)) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br />" . _NOSTORY . "<br /><br />";
		KWL_DrawMain($VAR);
	} else {
		if ($CONF['ENABLE_QUOTE']) $otxt = KWL_QuoteText($A['Content'],$A['Author']);
		$A['Content'] = KWL_ParseContent($A['Content'],$A['ParseLevel']);
		KWL_DrawComment($A,$where);
		if (isset($aid)) $where .= "&aid=$aid";
		if (isset($story)) $where .= "&story=$story";
		if (isset($p)) $where .= "&p=$p";
		if (isset($cmode)) $where .= "&cmode=$cmode";
		if (isset($comment_sort)) $where .= "&comment_sort=$comment_sort";
		$size['name'] = KWL_FormSize(15);
		$size['text'] = KWL_FormSize(32);
		if ($A['email']) echo "<!-- msg will send via email -->\n";
		KWL_PostComment($rid,$A['TopRid'],$where,$A['score'],1,$otxt);
	}
} else if(isset($sid)) {
	include("include/header.inc.php");
	$A = KWL_GetStory($sid);
	if (!$A) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br />" . _NOSTORY . "<br /><br />";
		KWL_DrawMain($VAR);
	} else {
		KWL_DrawStory($A);
		echo "<br />\n";
		if ($CONF['ENABLE_QUOTE']) $otxt = KWL_QuoteText($A['Content'],$A['Author']);
		KWL_PostComment($sid,$sid,"comments.php?rid=$sid&amp;story=$sid&amp;bm=1",'','',$otxt);
	}
} else KWL_Redirect("$CONF[G_URL]");
include("include/footer.inc.php");
?>
